@@ -20,6 +20,7 @@ import csv
 import dateparser
 from   datetime import date
 from   datetime import datetime as dt
+from   dateutil import tz
 import humanize
 import json as jsonlib
 from   lxml import etree
@@ -29,6 +30,7 @@ from   PIL import Image, ImageFile
 import plac
 from   recordclass import recordclass
 import shutil
+from   sidetrack import set_debug, log
 import sys
 import xmltodict
 
@@ -38,7 +40,6 @@ ImageFile.LOAD_TRUNCATED_IMAGES = True
 
 import microarchiver
 from microarchiver import print_version
-from .debug import set_debug, log
 from .exceptions import *
 from .files import readable, writable, file_in_use, file_is_empty
 from .files import filename_extension, filename_basename, module_path
@@ -233,11 +234,11 @@ Command-line options summary
 
     debugging = debug != 'OUT'
     if debugging:
-        set_debug(True, debug)
+        if __debug__: set_debug(True, debug)
         import faulthandler
         faulthandler.enable()
 
-    if __debug__: log('='*8 + ' started {}' + '='*8, dt.now().strftime(_DATE_FORMAT))
+    if __debug__: log('='*8 + ' started {}' + '='*8, timestamp())
 
     if version:
         print_version()
@@ -729,27 +730,24 @@ def xml_filename(article, article_dir = ''):
     return path.join(article_dir, filename)
 
 
-def jats_filename(article, jats_dir = ''):
+def pmc_basename(article):
     issn_no_dash = _MICROPUBLICATION_ISSN.replace('-', '')
-    # microPublication's volume number = the year.
-    volume = str(date.today().year)
-    filename = issn_no_dash + '-' + volume + '-' + tail_of_doi(article) + '.xml'
+    volume = str(parse_datetime(article.date).year)
+    return issn_no_dash + '-' + volume + '-' + tail_of_doi(article)
+
+
+def jats_filename(article, jats_dir = ''):
+    filename = pmc_basename(article) + '.xml'
     return path.join(jats_dir, filename)
 
 
 def pmc_pdf_filename(article, article_dir = ''):
-    issn_no_dash = _MICROPUBLICATION_ISSN.replace('-', '')
-    # microPublication's volume number = the year.
-    volume = str(date.today().year)
-    filename = issn_no_dash + '-' + volume + '-' + tail_of_doi(article) + '.pdf'
+    filename = pmc_basename(article) + '.pdf'
     return path.join(article_dir, filename)
 
 
 def pmc_zip_filename(article, article_dir = ''):
-    issn_no_dash = _MICROPUBLICATION_ISSN.replace('-', '')
-    # microPublication's volume number = the year.
-    volume = str(date.today().year)
-    filename = issn_no_dash + '-' + volume + '-' + tail_of_doi(article) + '.zip'
+    filename = pmc_basename(article) + '.zip'
     return path.join(article_dir, filename)
 
 
@@ -830,6 +828,11 @@ def parse_datetime(string):
 function with predefined settings.'''
     return dateparser.parse(string, settings = {'RETURN_AS_TIMEZONE_AWARE': True})
 
+
+def timestamp():
+    '''Return a string describing the date and time right now.'''
+    return dt.now(tz = tz.tzlocal()).strftime(_DATE_FORMAT)
+
 
 # Main entry point.
 # .............................................................................
